plugins.core package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   plugins.core.error
   plugins.core.navigation
   plugins.core.startup

Module contents
---------------

.. automodule:: plugins.core
   :members:
   :undoc-members:
   :show-inheritance:
